@@ -58,10 +58,10 @@ void ProfileChangerWidget::refreshIcon() {
     QString profileName = this->getProfileName();
 
     if ( profileName == "silent" ) {
-        showIconSilent(); 
+        showIconGeneral();
     }
     else {
-        showIconGeneral();
+        showIconSilent(); 
     }
 }
     
@@ -96,6 +96,12 @@ void ProfileChangerWidget::onShowSettingsDialog()
     dialog->show();
 }
 
+void ProfileChangerWidget::onHomeScreenChanged(bool isOnCurrentHomescreen)
+{
+    if(isOnCurrentHomescreen)
+        refreshIcon();
+}
+
 void ProfileChangerWidget::reloadSettings()
 {
     this->setGeometry(this->x(), this->y(),
